@@ -2,7 +2,7 @@
  *
  *  littler - Provides hash-bang (#!) capability for R (www.r-project.org)
  *
- *  Copyright (C) 2006 Jeffrey Horner and Dirk Eddelbuettel
+ *  Copyright (C) 2006, 2007 Jeffrey Horner and Dirk Eddelbuettel
  *
  *  littler is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: littler.c 94 2006-10-06 14:49:15Z jeffrey.horner $
+ *  $Id: littler.c 116 2007-02-19 20:43:16Z jeffrey.horner $
  */
 
 #include <getopt.h>
@@ -36,36 +36,31 @@
 #include "littler.h"
 
 #include <R.h>
+#include <Rembedded.h>
 #include <Rversion.h>
 #include <Rdefines.h>
 #define R_INTERFACE_PTRS
 #include <Rinterface.h>
 #include <R_ext/Parse.h>
 
-#define R_240 132096 /* This is set in Rversion.h */
-
 int verbose=0;
+
+#if R_VERSION < R_Version(2,5,0)
 extern int R_Visible; /* We're cheating here, as this is undocumented and not in the
                        * R embedded interface.
 					   * 
                        * This variable controls when an expression is printed
-                       * via PrintValue()
+                       * via PrintValue(). 
+					   *
+					   * Looks like this will go away in R 2.5.x
                        */
+#endif
 
 /* these two are being filled by autoconf and friends via config.h */
 /* VERSION */
 const char *programName = PACKAGE;
 const char *binaryName = "r";
 
-#if (R_VERSION < R_240) /* we can delete this code after R 2.4.0 release */
-/* 
- * Exported by libR
- * Shouldn't this prototype exist in a header?
- * It will in R-2.4.x.
- */
-extern int Rf_initEmbeddedR(int argc, char *argv[]);
-#endif
-
 #ifndef HAVE_SETENV
 int  setenv(char *name, char *value, int clobber){
 	char   *cp;
@@ -297,14 +292,29 @@ int parse_eval(membuf_t *pmb, char *line, int lineno){
 
 	PROTECT(cmdSexp = allocVector(STRSXP, 1));
 	SET_STRING_ELT(cmdSexp, 0, mkChar((char*)mb->buf));
+
+	/* R_ParseVector gets a new argument in R 2.5.x */
+	#if R_VERSION >= R_Version(2,5,0)
+	cmdexpr = PROTECT(R_ParseVector(cmdSexp, -1, &status,R_NilValue));
+	#else
 	cmdexpr = PROTECT(R_ParseVector(cmdSexp, -1, &status));
+	#endif
+
 	switch (status){
 		case PARSE_OK:
 			/* Loop is needed here as EXPSEXP might be of length > 1 */
 			for(i = 0; i < length(cmdexpr); i++){
 				ans = R_tryEval(VECTOR_ELT(cmdexpr, i),NULL,&errorOccurred);
 				if (errorOccurred) return 1;
+
+				#if R_VERSION < R_Version(2,5,0)
+				/* We won't be able to test for R_Visible after R 2.5.x.
+				 * need to figure out why...
+				 */
 				if (verbose && R_Visible){
+				#else 
+				if (verbose){
+				#endif
 					PrintValue(ans);
 				}
 			}
@@ -339,16 +349,6 @@ void littler_InitTempDir()
 {
 	char *tmp;
 
-	#if (R_VERSION < R_240) /* we can delete this code after R 2.4.0 release */
-	if (R_TempDir){
-		/* Undo R's InitTempdir() and do something sane */
-		if (rmdir(R_TempDir) != 0){
-			perror("Fatal Error: could not remove R's TempDir!");
-			exit(1);
-		}
-	}
-	#endif
-
 	tmp = getenv("TMPDIR");
 	if (tmp == NULL) {
 		tmp = getenv("TMP");
@@ -412,7 +412,7 @@ void showVersionAndExit() {
 					R_SVN_REVISION);
 		}
 	}
-  	printf("\n\nCopyright (C) 2006 Jeffrey Horner and Dirk Eddelbuettel\n"
+  	printf("\n\nCopyright (C) 2006, 2007 Jeffrey Horner and Dirk Eddelbuettel\n"
 	       "\n"
 	       "%s is free software and comes with ABSOLUTELY NO WARRANTY.\n"
 	       "You are welcome to redistribute it under the terms of the\n"
@@ -441,6 +441,26 @@ void showUsageAndExit() {
 	exit(-1);       
 }
 
+/* set seed for tempfile()  */
+void init_rand()
+{
+    unsigned int seed;
+#if HAVE_GETTIMEOFDAY
+  {
+    struct timeval tv;
+    gettimeofday (&tv, NULL);
+	/* changed uint64_t to unsigned int. Need to figure out why
+	 * PBR used that instead. */
+    seed = ((unsigned int) tv.tv_usec << 16) ^ tv.tv_sec;
+  }
+#elif HAVE_TIME
+    seed = (unsigned int) time(NULL);
+#else
+    /* unlikely, but use random contents */
+#endif
+    srand(seed);
+}
+
 int main(int argc, char **argv){
 
 	/* R embedded arguments, and optional arguments to be picked via cmdline switches */
@@ -554,15 +574,11 @@ int main(int argc, char **argv){
 	R_CStackLimit = -1;
 	#endif
 
-	#if (R_VERSION >= R_240) /* we'll take out the ifdef after R 2.4.0 release */
 	littler_InitTempDir();
-	#endif
 
 	Rf_initEmbeddedR(R_argc, R_argv);
 
-	#if (R_VERSION < R_240) /* we can delete this code after R 2.4.0 release */
-	littler_InitTempDir();
-	#endif
+	R_ReplDLLinit(); /* this is to populate the repl console buffers */
 
 	ptr_R_CleanUp = littler_CleanUp;
 
@@ -587,6 +603,9 @@ int main(int argc, char **argv){
 		setVar(install("argv"),R_NilValue,R_GlobalEnv);
 	}
 
+	/* for tempfile() to work correctly */
+	init_rand();
+
 	/* Now determine which R code to evaluate */
 
 	int exit_val;
